==> v3.12.4.8.tar.gz: qcad-3.12.4.8/ts/qcadgui_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>ExitTrialDialog</name>
    <message>
        <source>Trial Version</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Versione di prova</translation>
    </message>
    <message>
        <source>QCAD Trial</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">QCAD versione di prova</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Cannot find user manual at: %1</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Impossibile trovare il manuale utente in: %1</translation>
    </message>
    <message>
        <source>Unable to launch Qt Assistant (%1)</source>
        <translatorcomment>--exact match--
--file: linguist_it.ts--
Impossibile eseguire Qt Assistant (%1)</translatorcomment>
        <translation type="obsolete">Impossibile eseguire Qt Assistant (%1)</translation>
    </message>
</context>
<context>
    <name>RColorCombo</name>
    <message>
        <location filename="../src/gui/RColorCombo.cpp" line="+126"/>
        <source>Custom</source>
        <translatorcomment>--exact match--
--file: locale_it_BKChem.po--
Nessun oggetto dimensione selezionata con una posizione di testo personalizzato.
Nessun oggetto dimensione selezionata con una posizione di testo personalizzato
Personalizzato</translatorcomment>
        <translation>Personalizzato</translation>
    </message>
</context>
<context>
    <name>RMathLineEdit</name>
    <message>
        <location filename="../src/gui/RMathLineEdit.cpp" line="+156"/>
        <source>Invalid</source>
        <translation>Non valido</translation>
    </message>
</context>
<context>
    <name>RSingleApplication</name>
    <message>
        <source>This software is not intended for production use.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Questo software non è inteso per l&apos;uso in produzione.</translation>
    </message>
    <message>
        <source>To continue trying out QCAD, please restart the software.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Per continuare a provare QCAD, riavviare il software.</translation>
    </message>
    <message>
        <source>To start using QCAD without any limitations, please buy the full version for a small license fee from %1.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Per iniziare a utilizzare QCAD senza limitazioni, si prega di acquistare la versione completa da %1.</translation>
    </message>
</context>
</TS>

==> v3.22.1.2.tar.gz: qcad-3.22.1.2/ts/qcadgui_it.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="it_IT">
<context>
    <name>ExitTrialDialog</name>
    <message>
        <source>Trial Version</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Versione di prova</translation>
    </message>
    <message>
        <source>QCAD Trial</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">QCAD versione di prova</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Cannot find user manual at: %1</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Impossibile trovare il manuale utente in: %1</translation>
    </message>
    <message>
        <source>Unable to launch Qt Assistant (%1)</source>
        <translatorcomment>--exact match--
--file: linguist_it.ts--
Impossibile eseguire Qt Assistant (%1)</translatorcomment>
        <translation type="obsolete">Impossibile eseguire Qt Assistant (%1)</translation>
    </message>
</context>
<context>
    <name>RColorCombo</name>
    <message>
        <location filename="../src/gui/RColorCombo.cpp" line="+126"/>
        <source>Custom</source>
        <translation>Personalizzato</translation>
    </message>
</context>
<context>
    <name>REventHandler</name>
    <message>
        <location filename="../src/gui/REventHandler.cpp" line="+195"/>
        <source>Grid</source>
        <translation>Griglia</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>End</source>
        <translation>Fine</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>On Entity</source>
        <translation>Sull&apos;entità</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Perpendicular</source>
        <translation>Perpendicolare</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Tangential</source>
        <translation>Tangenziale</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Center</source>
        <translation>Centro</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Middle</source>
        <translation>Medio</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Intersection</source>
        <translation>Intersezione</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Reference</source>
        <translation>Riferimento</translation>
    </message>
</context>
<context>
    <name>RMathLineEdit</name>
    <message>
        <location filename="../src/gui/RMathLineEdit.cpp" line="+171"/>
        <source>Invalid</source>
        <translation>Non valido</translation>
    </message>
</context>
<context>
    <name>RSingleApplication</name>
    <message>
        <source>This software is not intended for production use.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Questo software non è inteso per l&apos;uso in produzione.</translation>
    </message>
    <message>
        <source>To continue trying out QCAD, please restart the software.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Per continuare a provare QCAD, riavviare il software.</translation>
    </message>
    <message>
        <source>To start using QCAD without any limitations, please buy the full version for a small license fee from %1.</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="obsolete">Per iniziare a utilizzare QCAD senza limitazioni, si prega di acquistare la versione completa da %1.</translation>
    </message>
</context>
</TS>
